# hagike

hagike是一个用于开发与部署的通用套件，由hagikehappy开发。

其内容包括以下几个子包：

1. utils: 通用工具，如常量表等
2. tools: 辅助工具，包括画图、基本图形化界面、分析工具等
3. system: 任务级并行运算系统
   1. interface: 调用系统内核的接口模板
   2. core: 系统内核
4. basics: 基本算法库
5. models: 模型套件
   1. cv: 计算机视觉类模型
   2. nlp: 自然语言处理类模型
   3. rl: 强化学习类模型
   4. template: 通用模型模板
   5. train: 训练与评估模板
   6. deploy: 部署模板
6. demos: 项目示例，用于快速基于hagike库创建新的套件

